@@ -12,20 +12,16 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+from collections import abc
 import re
 
-try:  # python 3
-    from collections import abc
-except ImportError:  # python 2
-    import collections as abc
-
 from oslotest import base
 
 from oslo_reports.models import base as base_model
 from oslo_reports import report
 
 
-class BasicView(object):
+class BasicView:
     def __call__(self, model):
         res = ""
         for k in sorted(model.keys()):
@@ -39,7 +35,7 @@ def basic_generator():
 
 class TestBasicReport(base.BaseTestCase):
     def setUp(self):
-        super(TestBasicReport, self).setUp()
+        super().setUp()
 
         self.report = report.BasicReport()
 
@@ -68,7 +64,7 @@ class TestBasicReport(base.BaseTestCase):
 
 class TestBaseModel(base.BaseTestCase):
     def test_submodel_attached_view(self):
-        class TmpView(object):
+        class TmpView:
             def __call__(self, model):
                 return '{len: ' + str(len(model.c)) + '}'
 
