@@ -17,10 +17,8 @@
 This package defines several text views with headers
 """
 
-import six
 
-
-class HeaderView(object):
+class HeaderView:
     """A Text View With a Header
 
     This view simply serializes the model and places the given
@@ -33,7 +31,7 @@ class HeaderView(object):
         self.header = header
 
     def __call__(self, model):
-        return six.text_type(self.header) + "\n" + six.text_type(model)
+        return f'{self.header}\n{model}'
 
 
 class TitledView(HeaderView):
@@ -50,4 +48,4 @@ class TitledView(HeaderView):
     FORMAT_STR = ('=' * 72) + "\n===={0: ^64}====\n" + ('=' * 72)
 
     def __init__(self, title):
-        super(TitledView, self).__init__(self.FORMAT_STR.format(title))
+        super().__init__(self.FORMAT_STR.format(title))
